@@ -30,7 +30,6 @@ from dimsdk import ID
 from dimsdk import ReliableMessage
 
 from ..protocol import LoginCommand
-from ..protocol import ReportCommand
 
 
 class LoginDBI(ABC):
@@ -48,46 +47,6 @@ class LoginDBI(ABC):
         raise NotImplemented
 
 
-class ReportDBI(ABC):
-    """ Report(online/offline) Command Table """
-
-    #
-    #   online/offline command
-    #
-    @abstractmethod
-    def online_command(self, identifier: ID) -> Optional[ReportCommand]:
-        raise NotImplemented
-
-    @abstractmethod
-    def save_online_command(self, identifier: ID, content: ReportCommand) -> bool:
-        raise NotImplemented
-
-
-class OnlineDBI(ABC):
-    """ Online Status Table """
-
-    #
-    #   online users
-    #
-    @abstractmethod
-    def active_users(self) -> Set[ID]:
-        raise NotImplemented
-
-    @abstractmethod
-    def socket_addresses(self, identifier: ID) -> Set[Tuple[str, int]]:
-        raise NotImplemented
-
-    @abstractmethod
-    def add_socket_address(self, identifier: ID, address: Tuple[str, int]) -> Set[Tuple[str, int]]:
-        """ return new address set """
-        raise NotImplemented
-
-    @abstractmethod
-    def remove_socket_address(self, identifier: ID, address: Tuple[str, int]) -> Set[Tuple[str, int]]:
-        """ return new address set """
-        raise NotImplemented
-
-
 class ProviderDBI(ABC):
     """ Provider Stations Table """
 
@@ -112,6 +71,6 @@ class ProviderDBI(ABC):
         raise NotImplemented
 
 
-class SessionDBI(LoginDBI, ReportDBI, OnlineDBI, ProviderDBI, ABC):
+class SessionDBI(LoginDBI, ProviderDBI, ABC):
     """ Session Database """
     pass
