@@ -135,8 +135,11 @@ class InnerMessenger(OctopusMessenger):
 
     # Override
     def deliver_message(self, msg: ReliableMessage) -> List[ReliableMessage]:
+        priority = 0  # NORMAL
+        if msg.receiver.is_broadcast:
+            priority = 1  # SLOWER
         octopus = self.octopus
-        return octopus.outgo_message(msg=msg)
+        return octopus.outgo_message(msg=msg, priority=priority)
 
 
 class OuterMessenger(OctopusMessenger):
@@ -151,8 +154,11 @@ class OuterMessenger(OctopusMessenger):
 
     # Override
     def deliver_message(self, msg: ReliableMessage) -> List[ReliableMessage]:
+        priority = 0  # NORMAL
+        if msg.receiver.is_broadcast:
+            priority = 1  # SLOWER
         octopus = self.octopus
-        return octopus.income_message(msg=msg)
+        return octopus.income_message(msg=msg, priority=priority)
 
     # Override
     def handshake_success(self):
@@ -170,7 +176,7 @@ def create_messenger(user: ID, host: str, port: int, octopus, clazz) -> OctopusM
     station.data_source = facebook
     # 1. create session with SessionDB
     session = ClientSession(station=station, database=shared.sdb)
-    session.identifier = user
+    session.set_identifier(identifier=user)
     # 2. create messenger with session and MessageDB
     messenger = clazz(session=session, facebook=facebook, database=shared.mdb)
     assert isinstance(messenger, OctopusMessenger)
@@ -191,23 +197,13 @@ def create_terminal(messenger: ClientMessenger) -> Terminal:
     return terminal
 
 
-def create_inner_terminal(user: ID, host: str, port: int, octopus) -> Terminal:
-    messenger = create_messenger(user=user, host=host, port=port, octopus=octopus, clazz=InnerMessenger)
-    return create_terminal(messenger=messenger)
-
-
-def create_outer_terminal(octopus, user: ID, host: str, port: int) -> Terminal:
-    messenger = create_messenger(user=user, host=host, port=port, octopus=octopus, clazz=OuterMessenger)
-    return create_terminal(messenger=messenger)
-
-
 class Octopus(Runner, Logging):
 
     def __init__(self, database: SessionDBI, local_user: ID, local_host: str = '127.0.0.1', local_port: int = 9394):
         super().__init__()
         self.__database = database
         self.__user = local_user
-        self.__inner = create_inner_terminal(user=local_user, host=local_host, port=local_port, octopus=self)
+        self.__inner = self.create_inner_terminal(user=local_user, host=local_host, port=local_port)
         self.__outers: Set[Terminal] = set()
         self.__outer_map = weakref.WeakValueDictionary()
         self.__outer_lock = threading.Lock()
@@ -227,6 +223,14 @@ class Octopus(Runner, Logging):
         if terminal is not None:
             return terminal.messenger
 
+    def create_inner_terminal(self, user: ID, host: str, port: int) -> Terminal:
+        messenger = create_messenger(user=user, host=host, port=port, octopus=self, clazz=InnerMessenger)
+        return create_terminal(messenger=messenger)
+
+    def create_outer_terminal(self, user: ID, host: str, port: int) -> Terminal:
+        messenger = create_messenger(user=user, host=host, port=port, octopus=self, clazz=OuterMessenger)
+        return create_terminal(messenger=messenger)
+
     def add_index(self, identifier: ID, terminal: Terminal):
         with self.__outer_lock:
             # self.__outers.add(terminal)
@@ -234,7 +238,7 @@ class Octopus(Runner, Logging):
 
     def connect(self, host: str, port: int = 9394):
         user = self.__user
-        terminal = create_outer_terminal(octopus=self, user=user, host=host, port=port)
+        terminal = self.create_outer_terminal(user=user, host=host, port=port)
         with self.__outer_lock:
             self.__outers.add(terminal)
 
@@ -246,7 +250,8 @@ class Octopus(Runner, Logging):
     def stop(self):
         super().stop()
         inner = self.__inner
-        inner.stop()
+        if inner is not None:
+            inner.stop()
         with self.__outer_lock:
             outers = set(self.__outers)
         for out in outers:
@@ -292,38 +297,36 @@ class Octopus(Runner, Logging):
             self.connect(host=host, port=port)
         return False
 
-    def income_message(self, msg: ReliableMessage) -> List[ReliableMessage]:
+    def income_message(self, msg: ReliableMessage, priority: int = 0) -> List[ReliableMessage]:
         """ redirect message from remote station """
-        receiver = msg.receiver
         messenger = self.inner_messenger
-        if messenger.send_reliable_message(msg=msg):
+        if messenger.send_reliable_message(msg=msg, priority=priority):
             sig = get_sig(msg=msg)
-            self.info(msg='redirected msg (%s) for receiver (%s)' % (sig, receiver))
+            self.info(msg='redirected msg (%s) for receiver (%s)' % (sig, msg.receiver))
             # no need to respond receipt for station
             return []
         sig = get_sig(msg=msg)
-        self.error(msg='failed to redirect msg (%s) for receiver (%s)' % (sig, receiver))
+        self.error(msg='failed to redirect msg (%s) for receiver (%s)' % (sig, msg.receiver))
         return []
 
-    def outgo_message(self, msg: ReliableMessage) -> List[ReliableMessage]:
+    def outgo_message(self, msg: ReliableMessage, priority: int = 0) -> List[ReliableMessage]:
         """ redirect message to remote station """
-        receiver = msg.receiver
         target = ID.parse(identifier=msg.get('neighbor'))
         if target is None:
             # target station not found
-            self.info(msg='cannot get target station for receiver (%s)' % receiver)
+            self.info(msg='cannot get target station for receiver (%s)' % msg.receiver)
             return []
         messenger = self.get_outer_messenger(identifier=target)
         if messenger is None:
             # target station not my neighbor
-            self.info(msg='receiver (%s) is targeted to (%s), but not my neighbor' % (receiver, target))
+            self.info(msg='receiver (%s) is targeted to (%s), but not my neighbor' % (msg.receiver, target))
             return []
         msg.pop('neighbor', None)
-        if messenger.send_reliable_message(msg=msg):
+        if messenger.send_reliable_message(msg=msg, priority=priority):
             sig = get_sig(msg=msg)
-            self.info(msg='redirected msg (%s) to target (%s) for receiver (%s)' % (sig, target, receiver))
+            self.info(msg='redirected msg (%s) to target (%s) for receiver (%s)' % (sig, target, msg.receiver))
             # no need to respond receipt for station
             return []
         sig = get_sig(msg=msg)
-        self.error(msg='failed to redirect msg (%s) to target (%s) for receiver (%s)' % (sig, target, receiver))
+        self.error(msg='failed to redirect msg (%s) to target (%s) for receiver (%s)' % (sig, target, msg.receiver))
         return []
