@@ -54,12 +54,15 @@ class GlobalVariable:
         self.pusher: Optional[Pusher] = None
 
 
-def init_database(shared: GlobalVariable):
+def create_database(shared: GlobalVariable) -> (AccountDBI, MessageDBI, SessionDBI):
     config = shared.config
+    root = config.database_root
+    public = config.database_public
+    private = config.database_private
     # create database
-    adb = AccountDatabase(root=config.root, public=config.public, private=config.private)
-    mdb = MessageDatabase(root=config.root, public=config.public, private=config.private)
-    sdb = SessionDatabase(root=config.root, public=config.public, private=config.private)
+    adb = AccountDatabase(root=root, public=public, private=private)
+    mdb = MessageDatabase(root=root, public=public, private=private)
+    sdb = SessionDatabase(root=root, public=public, private=private)
     adb.show_info()
     mdb.show_info()
     sdb.show_info()
@@ -71,25 +74,25 @@ def init_database(shared: GlobalVariable):
     for node in neighbors:
         print('adding neighbor node: (%s:%d), ID="%s"' % (node.host, node.port, node.identifier))
         sdb.add_neighbor(host=node.host, port=node.port, identifier=node.identifier)
+    return adb, mdb, sdb
 
 
-def init_facebook(shared: GlobalVariable) -> CommonFacebook:
+def create_facebook(shared: GlobalVariable) -> CommonFacebook:
     # set account database
-    facebook = CommonFacebook()
-    facebook.database = shared.adb
+    facebook = CommonFacebook(database=shared.adb)
     shared.facebook = facebook
     # set current station
-    station = shared.config.station
-    if station is not None:
+    sid = shared.config.station_id
+    if sid is not None:
         # make sure private key exists
-        assert facebook.private_key_for_visa_signature(identifier=station) is not None, \
-            'failed to get sign key for current station: %s' % station
-        print('set current user: %s' % station)
-        facebook.current_user = facebook.user(identifier=station)
+        assert facebook.private_key_for_visa_signature(identifier=sid) is not None, \
+            'failed to get sign key for current station: %s' % sid
+        print('set current user: %s' % sid)
+        facebook.current_user = facebook.user(identifier=sid)
     return facebook
 
 
-def init_ans(shared: GlobalVariable) -> AddressNameService:
+def create_ans(shared: GlobalVariable) -> AddressNameService:
     ans = AddressNameServer()
     factory = ID.factory()
     ID.register(factory=ANSFactory(factory=factory, ans=ans))
@@ -99,7 +102,7 @@ def init_ans(shared: GlobalVariable) -> AddressNameService:
     return ans
 
 
-def init_pusher(shared: GlobalVariable) -> Pusher:
+def create_pusher(shared: GlobalVariable) -> Pusher:
     pusher = DefaultPusher(facebook=shared.facebook)
     shared.pusher = pusher
     # start PushCenter
@@ -109,7 +112,7 @@ def init_pusher(shared: GlobalVariable) -> Pusher:
     return pusher
 
 
-def init_dispatcher(shared: GlobalVariable) -> Dispatcher:
+def create_dispatcher(shared: GlobalVariable) -> Dispatcher:
     # create dispatcher
     dispatcher = Dispatcher()
     dispatcher.database = shared.mdb
@@ -141,9 +144,9 @@ def init_dispatcher(shared: GlobalVariable) -> Dispatcher:
 
 # noinspection PyUnusedLocal
 def stop_dispatcher(shared: GlobalVariable) -> bool:
-    # stop Dispatcher
-    dispatcher = Dispatcher()
-    dispatcher.stop()
+    # TODO: stop Dispatcher
+    # dispatcher = Dispatcher()
+    # dispatcher.stop()
     return True
 
 
